@@ -19,31 +19,19 @@ from .clouds import CloudType
 from .const import UNWANTED_ATTRIBS
 from .day_map import DAY_MAP
 from .events import EventHandler, LandroidEvent
-from .exceptions import (
-    AuthorizationError,
-    MQTTException,
-    NoOneTimeScheduleError,
-    NoPartymodeError,
-    OfflineError,
-)
+from .exceptions import AuthorizationError, MQTTException
 from .helpers import convert_to_time, get_logger
 from .utils import (
     MQTT,
     Battery,
     Blades,
-    Capability,
-    Command,
     DeviceCapability,
+    DeviceHandler,
     Location,
-    MQTTData,
     Orientation,
-    Rainsensor,
-    Schedule,
     ScheduleType,
-    States,
-    StateType,
     Statistic,
-    Zone,
+    Weekdays,
 )
 from .utils.schedules import TYPE_TO_STRING
 
@@ -61,6 +49,8 @@ class WorxCloud(dict):
     There are no public available API documentation available.
     """
 
+    __device: str | None = None
+
     def __init__(
         self,
         username: str,
@@ -149,38 +139,17 @@ class WorxCloud(dict):
         self._username = username
         self._cloud = cloud
         self._auth_result = False
-        self._dev_id = index
         self._log = get_logger("pyworxcloud")
         self._raw = None
-        self._mqtt_data = None
+
         self._save_zones = None
         self._verify_ssl = verify_ssl
         self._events = EventHandler()
 
-        # Set default attribute values
-        ###############################
-        self.accessories = None
-        self.battery = Battery()
-        self.blades = Blades()
-        self.error = States(StateType.ERROR)
-        self.gps = Location()
-        self.locked = False
+        # Dict of devices, identified by name
+        self.devices = {}
+
         self.mqtt = None
-        self.mqttdata = MQTTData()
-        self.online = False
-        self.orientation = Orientation([0, 0, 0])
-        self.capabilities = Capability()
-        self.partymode_enabled = False
-        self.product = []
-        self.rainsensor = Rainsensor()
-        self.rssi = None
-        self.schedules: dict[str, Any] = {"time_extension": 0, "active": True}
-        self.serial_number = None
-        self.status = States()
-        self.torque = None
-        self.updated = "never"
-        self.work_time = 0
-        self.zone = Zone()
 
     def __enter__(self):
         """Default actions using with statement."""
@@ -213,9 +182,11 @@ class WorxCloud(dict):
 
         return True
 
-    def update_attribute(self, attr: str | None, key: str, value: Any) -> None:
+    def update_attribute(
+        self, device: str, attr: str | None, key: str, value: Any
+    ) -> None:
         """Used as callback to update value."""
-        chattr = self
+        chattr = self.devices[device]
         if not isinstance(attr, type(None)):
             for level in attr.split(";;"):
                 if hasattr(chattr, level):
@@ -240,14 +211,14 @@ class WorxCloud(dict):
     def disconnect(self) -> None:
         """Close API connections."""
         if self.mqtt.connected:
-            topic = self.mqttdata.topics["out"]
+            topic = self.mqtt.topics["out"]
             self.mqtt.unsubscribe(topic)
             self.mqtt.disconnect()
             self.mqtt.loop_stop()
 
     def connect(
         self,
-        index: int | None = None,
+        device: str | None = None,
         verify_ssl: bool = True,
         pahologger: bool = False,
     ) -> bool:
@@ -260,46 +231,19 @@ class WorxCloud(dict):
         Returns:
             bool: True if connection was successful, otherwise False.
         """
-        if not isinstance(index, type(None)):
-            if index != self._dev_id:
-                self._dev_id = index
+        if not isinstance(device, type(None)):
+            self.__device = device
 
-        self._get_mac_address()
-        self.product = {
-            "mac_address": self.mac_address,
-            "serial_number": self.serial_number,
-            "setup_location": self.setup_location,
-            "device": self._api.get_product_info(self.product_id),
-            "created_at": self.created_at,
-            "warranty": {
-                "expires": self.warranty_expires_at,
-                "registered": self.warranty_registered,
-            },
-            "sim": self.sim,
-            "registered_at": self.registered_at,
-        }
-
-        self.product.update(
-            {"board": self._api.get_board(self.product["device"]["board_id"])}
-        )
-        self.product.update(
-            {
-                "model": f'{self.product["device"]["default_name"]}{self.product["device"]["meters"]}'
-            }
-        )
-
-        # Get blades statistics
-        self.blades = Blades(data=self)
-
-        # Get battery information
-        self.battery = Battery(cycle_info=self)
+        self._fetch()
 
         # setup MQTT handler
         self.mqtt = MQTT(
-            self,
+            self.devices,
+            self._worx_mqtt_client_id,
             protocol=mqtt.MQTTv311,
         )
 
+        self.mqtt.endpoint = self._endpoint
         self.mqtt.reconnect_delay_set(60, 300)
 
         self.mqtt.on_message = self._forward_on_message
@@ -310,7 +254,7 @@ class WorxCloud(dict):
             mqttlog = self._log.getChild("PahoMQTT")
             self.mqtt.on_log = self._on_log
             self.mqtt.enable_logger(mqttlog)
-            self.mqttdata.logger = True
+            self.mqtt.logger = True
 
         with self._get_cert() as cert:
             self.mqtt.tls_set(certfile=cert)
@@ -318,29 +262,29 @@ class WorxCloud(dict):
         if not verify_ssl:
             self.mqtt.tls_insecure_set(True)
 
-        self.mqtt.connect(self.mqttdata["endpoint"], port=8883, keepalive=600)
+        self.mqtt.connect(self.mqtt.endpoint, port=8883, keepalive=600)
 
         self.mqtt.loop_start()
-        self.mqttdata["messages"]["raw"].update(
-            {
-                "in": self.raw_messages_in,
-                "out": self.raw_messages_out,
-            }
-        )
-        self.mqttdata["messages"]["filtered"].update(
-            {
-                "in": self.messages_in,
-                "out": self.messages_out,
-            }
-        )
-        self.mqttdata["registered"] = self.mqtt_registered
 
-        # Remove unwanted attribs
-        for attr in UNWANTED_ATTRIBS:
-            if hasattr(self, attr):
-                delattr(self, attr)
+        # self.mqttdata["messages"]["raw"].update(
+        #     {
+        #         "in": self.raw_messages_in,
+        #         "out": self.raw_messages_out,
+        #     }
+        # )
+        # self.mqttdata["messages"]["filtered"].update(
+        #     {
+        #         "in": self.messages_in,
+        #         "out": self.messages_out,
+        #     }
+        # )
+        # self.mqttdata["registered"] = self.mqtt_registered
 
-        convert_to_time(self, self.time_zone, callback=self.update_attribute)
+        # Convert time strings to objects.
+        for name, device in self.devices.items():
+            convert_to_time(
+                name, device, device.time_zone, callback=self.update_attribute
+            )
 
         return True
 
@@ -361,7 +305,7 @@ class WorxCloud(dict):
             profile = self._api.data
             if profile is None:
                 return False
-            self.mqttdata.update({"endpoint": profile["mqtt_endpoint"]})
+            self._endpoint = profile["mqtt_endpoint"]
             self._worx_mqtt_client_id = "android-" + self._api.uuid
         except:  # pylint: disable=bare-except
             return False
@@ -375,17 +319,6 @@ class WorxCloud(dict):
         with pfx_to_pem(certresp["pkcs12"]) as pem_cert:
             yield pem_cert
 
-    def _get_mac_address(self):
-        """Get device MAC address for identification."""
-        self._fetch()
-        self.mqttdata.topics.update(
-            {
-                "out": self.mqtt_topics["command_out"],
-                "in": self.mqtt_topics["command_in"],
-            },
-        )
-        del self.mqtt_topics
-
     def _forward_on_message(
         self,
         client,
@@ -395,143 +328,176 @@ class WorxCloud(dict):
     ):
         """MQTT callback method definition."""
         logger = self._log.getChild("mqtt.message_received")
-        logger.debug("Received MQTT message for %s - processing data", self.name)
-        self._fetch()
-        self._mqtt_data = message.payload.decode("utf-8")
-        self._decode_data(self._mqtt_data)
-        self._events.call(LandroidEvent.DATA_RECEIVED)
+        topic = message.topic
+        for name, topics in self.mqtt.topics.items():
+            if topics["out"] == topic:
+                break
 
-    def _decode_data(self, indata) -> None:
+        logger.debug(
+            "Received MQTT message for %s - processing data %s",
+            name,
+            message.payload.decode("utf-8"),
+        )
+
+        # self._fetch()
+        # self._mqtt_data = message.payload.decode("utf-8")
+
+        while not self.devices[name].is_decoded:
+            pass  # Await last dataset to be handled before sending a new into the handler
+
+        msg = message.payload.decode("utf-8")
+        if self.devices[name].raw_data == msg:
+            self._log.debug("Data was already present and not changed.")
+            return  # Data was identical, update was not needed
+
+        self.devices[name].raw_data = msg
+        self._decode_data(self.devices[name])
+        self._events.call(
+            LandroidEvent.DATA_RECEIVED, name=name, device=self.devices[name]
+        )
+
+    def _decode_data(self, device: DeviceHandler) -> None:
         """Decode incoming JSON data."""
+        device.is_decoded = False
+
         logger = self._log.getChild("decode_data")
-        logger.debug("Data decoding for %s started", self.name)
+        logger.debug("Data decoding for %s started", device.name)
+
+        if device.json_data:
+            logger.debug("Found JSON decoded data: %s", device.json_data)
+            data = device.json_data
+        elif device.raw_data:
+            logger.debug("Found raw data: %s", device.raw_data)
+            data = json.loads(device._mqtt_data)
+        else:
+            device.is_decoded = True
+            logger.debug("No valid data was found, skipping update for %s", device.name)
+            return
 
-        data = json.loads(indata)
         if "dat" in data:
-            self.firmware = data["dat"]["fw"]
-            self.rssi = data["dat"]["rsi"]
-            self.status.update(data["dat"]["ls"])
-            self.error.update(data["dat"]["le"])
+            device.rssi = data["dat"]["rsi"]
+            device.status.update(data["dat"]["ls"])
+            device.error.update(data["dat"]["le"])
 
-            self.zone.index = data["dat"]["lz"]
+            device.zone.index = data["dat"]["lz"]
 
-            self.locked = bool(data["dat"]["lk"])
+            device.locked = bool(data["dat"]["lk"])
 
             # Get battery info if available
             if "bt" in data["dat"]:
-                if len(self.battery) == 0:
-                    self.battery = Battery(data["dat"]["bt"])
+                if len(device.battery) == 0:
+                    device.battery = Battery(data["dat"]["bt"])
                 else:
-                    self.battery.set_data(data["dat"]["bt"])
+                    device.battery.set_data(data["dat"]["bt"])
             # Get device statistics if available
             if "st" in data["dat"]:
-                self.statistics = Statistic(data["dat"]["st"])
+                device.statistics = Statistic(data["dat"]["st"])
 
             # Get orientation if available.
             if "dmp" in data["dat"]:
-                self.orientation = Orientation(data["dat"]["dmp"])
+                device.orientation = Orientation(data["dat"]["dmp"])
 
             # Check for extra module availability
             if "modules" in data["dat"]:
                 if "4G" in data["dat"]["modules"]:
-                    self.gps = Location(
+                    device.gps = Location(
                         data["dat"]["modules"]["4G"]["gps"]["coo"][0],
                         data["dat"]["modules"]["4G"]["gps"]["coo"][1],
                     )
 
             # Get remaining rain delay if available
             if "rain" in data["dat"]:
-                self.rainsensor.triggered = bool(str(data["dat"]["rain"]["s"]) == "1")
-                self.rainsensor.remaining = int(data["dat"]["rain"]["cnt"])
+                device.rainsensor.triggered = bool(str(data["dat"]["rain"]["s"]) == "1")
+                device.rainsensor.remaining = int(data["dat"]["rain"]["cnt"])
 
         if "cfg" in data:
-            self.updated = data["cfg"]["dt"] + " " + data["cfg"]["tm"]
-            self.rainsensor.delay = int(data["cfg"]["rd"])
+            device.updated = data["cfg"]["dt"] + " " + data["cfg"]["tm"]
+            device.rainsensor.delay = int(data["cfg"]["rd"])
 
             # Fetch wheel torque
             if "tq" in data["cfg"]:
-                self.capabilities.add(DeviceCapability.TORQUE)
-                self.torque = data["cfg"]["tq"]
+                device.capabilities.add(DeviceCapability.TORQUE)
+                device.torque = data["cfg"]["tq"]
 
             # Fetch zone information
             if "mz" in data["cfg"]:
-                self.zone.starting_point = data["cfg"]["mz"]
-                self.zone.indicies = data["cfg"]["mzv"]
+                device.zone.starting_point = data["cfg"]["mz"]
+                device.zone.indicies = data["cfg"]["mzv"]
 
                 # Map current zone to zone index
-                self.zone.current = self.zone.indicies[self.zone.index]
+                device.zone.current = device.zone.indicies[device.zone.index]
 
             # Fetch main schedule
             if "sc" in data["cfg"]:
                 if "ots" in data["cfg"]["sc"]:
-                    self.capabilities.add(DeviceCapability.ONE_TIME_SCHEDULE)
+                    device.capabilities.add(DeviceCapability.ONE_TIME_SCHEDULE)
                 if "distm" in data["cfg"]["sc"]:
-                    self.capabilities.add(DeviceCapability.PARTY_MODE)
+                    device.capabilities.add(DeviceCapability.PARTY_MODE)
 
-                self.partymode_enabled = bool(str(data["cfg"]["sc"]["m"]) == "2")
+                device.partymode_enabled = bool(str(data["cfg"]["sc"]["m"]) == "2")
 
-                self.schedules["active"] = bool(str(data["cfg"]["sc"]["m"]) == "1")
-                self.schedules["time_extension"] = data["cfg"]["sc"]["p"]
+                device.schedules["active"] = bool(str(data["cfg"]["sc"]["m"]) == "1")
+                device.schedules["time_extension"] = data["cfg"]["sc"]["p"]
 
                 sch_type = ScheduleType.PRIMARY
-                schedule: dict = Schedule(sch_type)
-                self.schedules[TYPE_TO_STRING[sch_type]] = schedule["days"]
+                device.schedules.update({TYPE_TO_STRING[sch_type]: Weekdays()})
 
                 for day in range(0, len(data["cfg"]["sc"]["d"])):
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "start"
                     ] = data["cfg"]["sc"]["d"][day][0]
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "duration"
                     ] = data["cfg"]["sc"]["d"][day][1]
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "boundary"
                     ] = bool(data["cfg"]["sc"]["d"][day][2])
 
                     time_start = datetime.strptime(
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]]["start"],
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                            "start"
+                        ],
                         "%H:%M",
                     )
 
                     if isinstance(
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                             "duration"
                         ],
                         type(None),
                     ):
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                             "duration"
                         ] = "0"
 
                     duration = int(
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                             "duration"
                         ]
                     )
 
                     duration = duration * (
-                        1 + (int(self.schedules["time_extension"]) / 100)
+                        1 + (int(device.schedules["time_extension"]) / 100)
                     )
                     end_time = time_start + timedelta(minutes=duration)
 
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "end"
                     ] = end_time.time().strftime("%H:%M")
 
             # Fetch secondary schedule
             if "dd" in data["cfg"]["sc"]:
                 sch_type = ScheduleType.SECONDARY
-                schedule = Schedule(sch_type)
-                self.schedules[TYPE_TO_STRING[sch_type]] = schedule["days"]
+                device.schedules.update({TYPE_TO_STRING[sch_type]: Weekdays()})
 
                 for day in range(0, len(data["cfg"]["sc"]["d"])):
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "start"
                     ] = data["cfg"]["sc"]["dd"][day][0]
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "duration"
                     ] = data["cfg"]["sc"]["dd"][day][1]
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "boundary"
                     ] = bool(data["cfg"]["sc"]["dd"][day][2])
 
@@ -541,37 +507,41 @@ class WorxCloud(dict):
                     )
 
                     if isinstance(
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                             "duration"
                         ],
                         type(None),
                     ):
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                             "duration"
                         ] = "0"
 
                     duration = int(
-                        self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                        device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                             "duration"
                         ]
                     )
 
                     duration = duration * (
-                        1 + (int(self.schedules["time_extension"]) / 100)
+                        1 + (int(device.schedules["time_extension"]) / 100)
                     )
                     end_time = time_start + timedelta(minutes=duration)
 
-                    self.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
+                    device.schedules[TYPE_TO_STRING[sch_type]][DAY_MAP[day]][
                         "end"
                     ] = end_time.time().strftime("%H:%M")
 
-        convert_to_time(self, self.time_zone, callback=self.update_attribute)
-        logger.debug("Data for %s was decoded", self.name)
+        convert_to_time(
+            device.name, device, device.time_zone, callback=self.update_attribute
+        )
+
+        device.is_decoded = True
+        logger.debug("Data for %s was decoded", device.name)
 
     def _on_log(self, client, userdata, level, buf):
         """Capture MQTT log messages."""
         logger = self._log.getChild("mqtt.log")
-        logger.debug("MQTT log message for %s: %s", self.name, buf)
+        logger.debug("MQTT log message received: %s", buf)
 
     def _on_connect(
         self,
@@ -585,21 +555,27 @@ class WorxCloud(dict):
         logger = self._log.getChild("mqtt.connected")
         logger.debug(connack_string(rc))
         if rc == 0:
-            topic = self.mqttdata.topics["out"]
-            logger.debug(
-                "MQTT for %s connected, subscribing to topic '%s'", self.name, topic
-            )
-            client.subscribe(topic)
+            for name, topics in self.mqtt.topics.items():
+                topic = topics["out"]
+                logger.debug(
+                    "MQTT for %s connected, subscribing to topic '%s'", name, topic
+                )
+                client.subscribe(topic)
 
-            if isinstance(self._mqtt_data, type(None)):
-                logger.debug("MQTT chached data not found - requesting")
+            for name, device in self.devices.items():
+                device.mqtt = self.mqtt
+                if isinstance(device.raw_data, type(None)):
+                    logger.debug(
+                        "MQTT chached data not found for %s - requesting now", name
+                    )
 
-                mqp = self.mqtt.send(force=True)
-                if isinstance(mqp, type(None)):
-                    raise MQTTException("Couldn't send request to MQTT server.")
+                    mqp = device.mqtt.send(name, force=True)
+                    if isinstance(mqp, type(None)):
+                        raise MQTTException("Couldn't send request to MQTT server.")
 
-                while not mqp.is_published:
-                    time.sleep(0.1)
+                    while not mqp.is_published:
+                        pass
+                        # time.sleep(0.1)
 
             logger.debug("Setting MQTT connected flag TRUE")
             self.mqtt.connected = True
@@ -628,31 +604,38 @@ class WorxCloud(dict):
                     )
 
             if self.mqtt.connected:
-                logger.debug(
-                    "MQTT connection for %s was lost! (%s)", self.name, error_string(rc)
-                )
+                logger.debug("MQTT connection was lost! (%s)", error_string(rc))
 
             logger.debug("Setting MQTT connected flag FALSE")
             self.mqtt.connected = False
             self._events.call(LandroidEvent.MQTT_CONNECTION, state=self.mqtt.connected)
-            self.mqtt.unsubscribe(self.mqttdata.topics["out"])
+            for name, topics in self.mqtt.topics.items():
+                topic = topics["out"]
+                logger.debug(
+                    "MQTT for %s disconnected, unsubscribing from topic '%s'",
+                    name,
+                    topic,
+                )
+                client.unsubscribe(topic)
 
     def _fetch(self) -> None:
         """Fetch base API information."""
         self._api.get_products()
-        products = self._api.data
 
-        accessories = None
-        for attr, val in products[self._dev_id].items():
-            if attr == "accessories":
-                accessories = val
-            else:
-                setattr(self, str(attr), val)
+        for product in self._api.data:
+            if self.__device:
+                if product["name"] != self.__device:
+                    continue
 
-        if not accessories is None:
-            self.accessories = []
-            for key in accessories:
-                self.accessories.append(key)
+            device = DeviceHandler(self._api, product)
+            self.devices.update({product["name"]: device})
+
+            # device["accessories"] = None
+            # for attr, val in product.items():
+            # if attr == "accessories":
+            #     device["accessories"] = val
+            # else:
+            #     setattr(device, str(attr), val)
 
     def enumerate(self) -> int:
         """Fetch number of devices connected to the account.
@@ -667,238 +650,17 @@ class WorxCloud(dict):
         )
         return len(products)
 
-    # Service calls starts here
-    def send(self, data: str) -> None:
-        """Send raw JSON data to the device.
-
-        Args:
-            data (str): Data to be sent, formatted as a valid JSON object.
-
-        Raises:
-            OfflineError: Raised if the device isn't online.
-        """
-        if self.online:
-            self._log.debug("Sending %s to %s", data, self.name)
-            self.mqtt.send(data)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
     def update(self) -> None:
         """Retrive current device status."""
-        status = self._api.get_status(self.product["serial_number"])
-        status = str(status).replace("'", '"')
-        self._raw = status
+        for name, device in self.devices.items():
+            status = self._api.get_status(device.serial_number)
+            status = str(status).replace("'", '"')
 
-        self._decode_data(status)
+            while not device.is_decoded:
+                pass  # Await previous dataset to be handled before sending a new into the handler.
 
-    def start(self) -> None:
-        """Start mowing task
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            logger = self._log.getChild("command")
-            logger.debug("Sending START command to %s", self.name)
-            self.mqtt.command(Command.START)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def pause(self) -> None:
-        """Pause the mowing task
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            logger = self._log.getChild("command")
-            logger.debug("Sending PAUSE command to %s", self.name)
-            self.mqtt.command(Command.PAUSE)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def home(self) -> None:
-        """Stop the current task and go home.
-        If the knifes was turned on when this is called, it will return home with knifes still turned on.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            logger = self._log.getChild("command")
-            logger.debug("Sending HOME command to %s", self.name)
-            self.mqtt.command(Command.HOME)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def zonetraining(self) -> None:
-        """Start the zone training task.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            logger = self._log.getChild("command")
-            logger.debug("Sending ZONETRAINING command to %s", self.name)
-            self.mqtt.command(Command.ZONETRAINING)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def lock(self, enabled: bool) -> None:
-        """Set the device locked state.
-
-        Args:
-            enabled (bool): True will lock the device, False will unlock the device.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            if enabled:
-                logger = self._log.getChild("command")
-                logger.debug("Sending LOCK command to %s", self.name)
-                self.mqtt.command(Command.LOCK)
-            else:
-                logger = self._log.getChild("command")
-                logger.debug("Sending UNLOCK command to %s", self.name)
-                self.mqtt.command(Command.UNLOCK)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def restart(self):
-        """Reboot the device baseboard.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            logger = self._log.getChild("command")
-            logger.debug("Sending RESTART command to %s", self.name)
-            self.mqtt.command(Command.RESTART)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def safehome(self):
-        """Stop and go home with the blades off
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            logger = self._log.getChild("command")
-            logger.debug("Sending SAFEHOME command to %s", self.name)
-            self.mqtt.command(Command.SAFEHOME)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def raindelay(self, rain_delay: str | int) -> None:
-        """Set new rain delay.
-
-        Args:
-            rain_delay (str | int): Rain delay in minutes.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            if not isinstance(rain_delay, str):
-                rain_delay = str(rain_delay)
-            msg = f'"rd": {rain_delay}'
-            self.mqtt.send(msg)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def toggle_schedule(self, enable: bool) -> None:
-        """Turn on or off the schedule.
-
-        Args:
-            enable (bool): True is enabling the schedule, Fasle is disabling the schedule.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            if enable:
-                msg = '{"sc": {"m": 1}}'
-            else:
-                msg = '{"sc": {"m": 0}}'
-
-            self.mqtt.send(msg)
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def toggle_partymode(self, enabled: bool) -> None:
-        """Turn on or off the partymode.
-
-        Args:
-            enable (bool): True is enabling partymode, Fasle is disabling partymode.
-
-        Raises:
-            NoPartymodeError: Raised if the device does not support partymode.
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online and self.capabilities.check(DeviceCapability.PARTY_MODE):
-            if enabled:
-                msg = '{"sc": {"m": 2, "distm": 0}}'
-            else:
-                msg = '{"sc": {"m": 1, "distm": 0}}'
-
-            self.mqtt.send(msg)
-        elif not self.capabilities.check(DeviceCapability.PARTY_MODE):
-            raise NoPartymodeError("This device does not support Partymode")
-        elif not self.online:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def ots(self, boundary: bool, runtime: str | int) -> None:
-        """Start a One-Time-Schedule task
-
-        Args:
-            boundary (bool): If True the device will start the task cutting the edge.
-            runtime (str | int): Minutes to run the task before returning to dock.
-
-        Raises:
-            NoOneTimeScheduleError: OTS is not supported by the device.
-            OfflineError: Raised when the device is offline.
-        """
-        if self.online and self.capabilities.check(DeviceCapability.ONE_TIME_SCHEDULE):
-            if not isinstance(runtime, int):
-                runtime = int(runtime)
-
-            raw = {"sc": {"ots": {"bc": int(boundary), "wtm": runtime}}}
-            self.mqtt.send(json.dumps(raw))
-        elif not self.capabilities.check(DeviceCapability.ONE_TIME_SCHEDULE):
-            raise NoOneTimeScheduleError(
-                "This device does not support Edgecut-on-demand"
-            )
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
-
-    def setzone(self, zone: str | int) -> None:
-        """Set zone to be mowed when next mowing task is started.
-
-        Args:
-            zone (str | int): Zone to mow, valid possibilities are a number from 1 to 4.
-
-        Raises:
-            OfflineError: Raised if the device is offline.
-        """
-        if self.online:
-            if not isinstance(zone, int):
-                zone = int(zone)
-
-            current = self.zone_probability
-            new_zones = current
-            while not new_zones[self.mowing_zone] == zone:
-                tmp = []
-                tmp.append(new_zones[9])
-                for i in range(0, 9):
-                    tmp.append(new_zones[i])
-                new_zones = tmp
-
-            raw = {"mzv": new_zones}
-            self.mqtt.send(json.dumps(raw))
-        else:
-            raise OfflineError("The device is currently offline, no action was sent.")
+            device.raw_data = status
+            self._decode_data(device)
 
 
 @contextlib.contextmanager
