@@ -11,30 +11,29 @@ UNWANTED_ATTRIBS = [
     "battery_charge_cycles",
     "battery_charge_cycles_reset",
     "battery_charge_cycles_reset_at",
-    "mac_address",
-    "serial_number",
-    "setup_location",
-    "product_id",
-    "created_at",
     "app_settings",
+    "features",
     "iot_registered",
     "pending_radio_link_validation",
     "purchased_at",
     "push_notifications",
     "push_notifications_level",
-    "warranty_expires_at",
-    "warranty_registered",
-    "updated_at",
+    "created_at",
     "test",
-    "sim",
+    "updated_at",
+    "warranty_registered",
+    "warranty_expires_at",
+    "user_id",
+    "firmware_auto_upgrade",
+    "firmware_version",
+    "auto_schedule",
+    "auto_schedule_settings",
+    "lawn_perimeter",
+    "lawn_size",
+    "mqtt_topics",
+    "mqtt_endpoint",
     "messages_in",
     "messages_out",
     "raw_messages_in",
     "raw_messages_out",
-    "mqtt_registered",
-    "mqtt_endpoint",
-    "features",
-    "accessories",
-    "registered_at",
-    "firmware",
 ]
