@@ -1,4 +1,5 @@
 """Time formatting helpers."""
+from __future__ import annotations
 
 import re
 from datetime import datetime
@@ -6,7 +7,10 @@ from typing import Any
 
 import pytz
 
-from ..utils import __all__ as all_utils
+try:
+    from ..utils import __all__ as all_utils
+except:
+    pass
 
 DATE_FORMATS = [
     "%Y-%m-%d %H:%M:%S",
@@ -31,7 +35,9 @@ def string_to_time(dt_string: str, tz: str = "UTC") -> datetime:
     timezone = pytz.timezone(tz)
     for format in DATE_FORMATS:
         try:
-            dt_object = datetime.strptime(dt_string, format).astimezone(timezone)
+            dt_object = timezone.localize(
+                datetime.strptime(dt_string, format)
+            )  # .astimezone(timezone)
             break
         except ValueError:
             pass
@@ -41,6 +47,7 @@ def string_to_time(dt_string: str, tz: str = "UTC") -> datetime:
 
 @staticmethod
 def convert_to_time(
+    device: str,
     data: Any,
     tz: str = "UTC",
     expression: str | None = None,
@@ -64,7 +71,7 @@ def convert_to_time(
             parent += f";;{subkey}"
 
     for key in data:
-        if key.startswith("_") or key == 'master':
+        if key.startswith("_") or key == "devices":
             continue
 
         if not key in data:
@@ -75,6 +82,7 @@ def convert_to_time(
 
         if isinstance(value, tuple(all_utils)) or isinstance(value, dict):
             convert_to_time(
+                device=device,
                 data=value,
                 tz=tz,
                 expression=expression,
@@ -88,5 +96,5 @@ def convert_to_time(
             continue
 
         if len(hits) == 1:
-            newtime = string_to_time(hits[0])
-            callback(parent, key, newtime)
+            newtime = string_to_time(hits[0], tz)
+            callback(device, parent, key, newtime)
