@@ -3,13 +3,16 @@
 from .battery import Battery
 from .blades import Blades
 from .capability import Capability, DeviceCapability
+from .devices import DeviceHandler
 from .location import Location
-from .mqtt import MQTT, Command, MQTTData
+from .mqtt import MQTT, Command
 from .orientation import Orientation
+from .product import ProductInfo
 from .rainsensor import Rainsensor
-from .schedules import Schedule, ScheduleType
+from .schedules import Schedule, ScheduleType, Weekdays
 from .state import States, StateType
 from .statistics import Statistic
+from .warranty import Warranty
 from .zone import Zone
 
 __all__ = [
@@ -17,16 +20,19 @@ __all__ = [
     Blades,
     Capability,
     Command,
+    DeviceHandler,
     DeviceCapability,
     Location,
     MQTT,
-    MQTTData,
     Orientation,
+    ProductInfo,
     Rainsensor,
     Schedule,
     ScheduleType,
     States,
     StateType,
     Statistic,
+    Warranty,
+    Weekdays,
     Zone,
 ]
